flutter_custom_theme library

Make your own custom theme for custom components.

Easily share it between projects and customize.

Classes

ComplexCustomThemeData
Interface for custom theme data with nested CustomThemeData.
CustomThemeData
Interface for custom theme data implementation.
CustomThemeDataSet<T extends CustomThemeData>
Set of CustomThemeData's for light and dark themes.
CustomThemes
Storage for custom themes data.
StorageByType
Storage for instances by type.
StorageByTypeImpl<T>
Default implementation of a storage for instances by type.

Mixins

StorageByTypeMixin<T>
Mixin with functionality of storage for instances by type.

Typedefs

GetFromSubStorage<E> = E? Function(StorageByType storage)
Function to get element with type E from storage.